@@ -48,6 +48,7 @@ class SCPClient(object):
         self.preserve_times = False
         self._progress = progress
         self._recv_dir = ''
+        self._rename = False
         self._utime = None
         self._dirtimes = {}
 
@@ -103,13 +104,24 @@ class SCPClient(object):
             and directories.
         @type preserve_times: bool
         """
+        if not isinstance(remote_path, (list, tuple)):
+            remote_path = [remote_path]
+        remote_path = [_sh_quote(r) for r in remote_path]
         self._recv_dir = local_path or os.getcwd()
+        self._rename = len(remote_path) == 1 and not os.path.isdir(local_path)
+        if len(remote_path) > 1:
+            if not os.path.exists(self._recv_dir):
+                msg = "Local path '%s' does not exist" % self._recv_dir
+                raise SCPException(msg)
+            elif not os.path.isdir(self._recv_dir):
+                msg = "Local path '%s' is not a directory" % self._recv_dir
+                raise SCPException(msg)
         rcsv = ('', ' -r')[recursive]
         prsv = ('', ' -p')[preserve_times]
         self.channel = self.transport.open_session()
         self.channel.settimeout(self.socket_timeout)
-        self.channel.exec_command("scp%s%s -f %s" %
-                                  (rcsv, prsv, _sh_quote(remote_path)))
+        self.channel.exec_command("scp%s%s -f %s" % (rcsv, prsv,
+                                                     ' '.join(remote_path)))
         self._recv_all()
 
         if self.channel:
@@ -242,7 +254,7 @@ class SCPClient(object):
             try:
                 command[code](msg[1:])
             except KeyError:
-                raise SCPException(repr(msg))
+                raise SCPException(str(msg).strip())
         # directory times can't be set until we're done writing files
         self._set_dirtimes()
 
@@ -264,6 +276,9 @@ class SCPClient(object):
             mode = int(parts[0], 8)
             size = int(parts[1])
             path = os.path.join(self._recv_dir, parts[2])
+            if self._rename:
+                path = self._recv_dir
+                self._rename = False
         except:
             chan.send('\x01')
             chan.close()
@@ -272,7 +287,7 @@ class SCPClient(object):
         try:
             file_hdl = file(path, 'wb')
         except IOError, e:
-            chan.send('\x01' + e.message)
+            chan.send('\x01' + str(e))
             chan.close()
             raise
 
@@ -317,6 +332,9 @@ class SCPClient(object):
         try:
             mode = int(parts[0], 8)
             path = os.path.join(self._recv_dir, parts[2])
+            if self._rename:
+                path = self._recv_dir
+                self._rename = False
         except:
             self.channel.send('\x01')
             raise SCPException('Bad directory format')
@@ -331,7 +349,7 @@ class SCPClient(object):
             self._utime = None
             self._recv_dir = path
         except (OSError, SCPException), e:
-            self.channel.send('\x01' + e.message)
+            self.channel.send('\x01' + str(e))
             raise
 
     def _recv_popd(self, *cmd):
